@@ -7,7 +7,7 @@ __PACKAGE__->table("artist");
 
 __PACKAGE__->add_columns(
   artistid => { data_type => 'integer', is_auto_increment => 1 },
-  name     => { data_type => 'text', },
+  name     => { data_type => 'text' },
 );
 
 __PACKAGE__->set_primary_key('artistid');
